Alternative modules for handling Excel files — XlsxWriter Documentation

### Navigation

- index
- next |
- previous |
- XlsxWriter Documentation »

# Alternative modules for handling Excel files

The following are some Python alternatives to XlsxWriter.

## XLWT

From the xlwt page on PyPI:

> Library to create spreadsheet files compatible with MS Excel 97/2000/XP/2003 XLS files, on any platform, with Python 2.3 to 2.7.

> xlwt is a library for generating spreadsheet files that are compatible with Excel 97/2000/XP/2003, OpenOffice.org Calc, and Gnumeric. xlwt has full support for Unicode. Excel spreadsheets can be generated on any platform without needing Excel or a COM server. The only requirement is Python 2.3 to 2.7.

## XLRD

From the xlrd page on PyPI:

> Library for developers to extract data from Microsoft Excel (tm) spreadsheet files Extract data from Excel spreadsheets (.xls and .xlsx, versions 2.0 onwards) on any platform. Pure Python (2.6, 2.7, 3.2+). Strong support for Excel dates. Unicode-aware.

## OpenPyXL

From the openpyxl page on PyPI:

> A Python library to read/write Excel 2007 xlsx/xlsm files. Openpyxl is a pure python reader and writer of Excel OpenXML files. It is ported from the PHPExcel project.

### Navigation

- index
- next |
- previous |
- XlsxWriter Documentation »